summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorphajdan.jr@chromium.org <phajdan.jr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-21 22:48:09 +0000
committerphajdan.jr@chromium.org <phajdan.jr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-21 22:48:09 +0000
commit1e09ec8405edea095b9c1a064197d44098a02620 (patch)
tree3ccc095a457a6b1d46f1881f72e338ce7f46dc4b
parent688c779b257790393623cbce64734e979d5eb675 (diff)
downloadchromium_src-1e09ec8405edea095b9c1a064197d44098a02620.zip
chromium_src-1e09ec8405edea095b9c1a064197d44098a02620.tar.gz
chromium_src-1e09ec8405edea095b9c1a064197d44098a02620.tar.bz2
GTTF: No more FLAKY_ .
Please note that FLAKY_ tests have been ignored anyway. When tests started crashing, people just flipped that to DISABLED_ . Why not go straight to DISABLED_ then, so that we avoid wasting time on stupid test prefix games? With DISABLED_ it is clear to everyone that there is no coverage from given test. FLAKY_ creates an illusion of coverage, while in fact the test is still ignored. If a FLAKY_ test fails and nobody notices, does it still make a sound? ;-) Finally, note that gtest has a --gtest_also_run_disabled_tests if you need to run tests manually. TBR=jam BUG=none Review URL: https://codereview.chromium.org/11664013 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@174472 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--base/test/test_suite.cc47
-rw-r--r--base/test/test_suite.h19
-rw-r--r--chrome/browser/browser_keyevents_browsertest.cc2
-rw-r--r--chrome/browser/extensions/api/management/management_browsertest.cc2
-rw-r--r--chrome/browser/extensions/api/record/record_api_test.cc2
-rw-r--r--chrome/browser/extensions/crx_installer_browsertest.cc2
-rw-r--r--chrome/browser/extensions/extension_resource_request_policy_apitest.cc2
-rw-r--r--chrome/browser/extensions/extension_tabs_apitest.cc2
-rw-r--r--chrome/browser/history/history_unittest.cc2
-rw-r--r--chrome/browser/logging_chrome_browsertest.cc2
-rw-r--r--chrome/browser/net/load_timing_observer_browsertest.cc2
-rw-r--r--chrome/browser/performance_monitor/performance_monitor_browsertest.cc3
-rw-r--r--chrome/browser/prerender/prerender_browsertest.cc2
-rw-r--r--chrome/browser/printing/print_dialog_cloud_interative_uitest.cc2
-rw-r--r--chrome/browser/sync/profile_sync_service_unittest.cc2
-rw-r--r--chrome/browser/sync/test/integration/sync_errors_test.cc2
-rw-r--r--chrome/browser/tab_restore_browsertest.cc2
-rw-r--r--chrome/browser/ui/panels/panel_browsertest.cc2
-rw-r--r--chrome/browser/ui/webui/options/chromeos/guest_mode_options_ui_browsertest.cc2
-rw-r--r--chrome/browser/ui/webui/options/options_ui_browsertest.cc2
-rw-r--r--chrome/common/time_format_unittest.cc2
-rw-r--r--chrome/test/data/webui/ntp4.js2
-rw-r--r--chrome/test/data/webui/sandboxstatus_browsertest.js10
-rw-r--r--chrome/test/ppapi/ppapi_browsertest.cc2
-rw-r--r--chrome_frame/test/navigation_test.cc2
-rw-r--r--chrome_frame/test/test_with_web_server.cc19
-rw-r--r--chrome_frame/test/ui_test.cc22
-rw-r--r--content/public/test/test_launcher.cc4
-rw-r--r--dbus/bus_unittest.cc2
-rw-r--r--media/ffmpeg/ffmpeg_regression_tests.cc32
-rw-r--r--net/dns/dns_config_service_unittest.cc2
-rw-r--r--net/url_request/url_request_unittest.cc6
-rw-r--r--remoting/host/linux/x_server_clipboard_unittest.cc2
33 files changed, 70 insertions, 140 deletions
diff --git a/base/test/test_suite.cc b/base/test/test_suite.cc
index 824fbc6..c5c3368 100644
--- a/base/test/test_suite.cc
+++ b/base/test/test_suite.cc
@@ -78,8 +78,6 @@ class TestClientInitializer : public testing::EmptyTestEventListener {
} // namespace
-const char TestSuite::kStrictFailureHandling[] = "strict_failure_handling";
-
TestSuite::TestSuite(int argc, char** argv) : initialized_command_line_(false) {
PreInitialize(argc, argv, true);
}
@@ -124,44 +122,10 @@ void TestSuite::PreInitialize(int argc, char** argv,
// static
-bool TestSuite::IsMarkedFlaky(const testing::TestInfo& test) {
- return strncmp(test.name(), "FLAKY_", 6) == 0;
-}
-
-// static
bool TestSuite::IsMarkedMaybe(const testing::TestInfo& test) {
return strncmp(test.name(), "MAYBE_", 6) == 0;
}
-// static
-bool TestSuite::ShouldIgnoreFailure(const testing::TestInfo& test) {
- if (CommandLine::ForCurrentProcess()->HasSwitch(kStrictFailureHandling))
- return false;
- return IsMarkedFlaky(test);
-}
-
-// static
-bool TestSuite::NonIgnoredFailures(const testing::TestInfo& test) {
- return test.should_run() && test.result()->Failed() &&
- !ShouldIgnoreFailure(test);
-}
-
-int TestSuite::GetTestCount(TestMatch test_match) {
- testing::UnitTest* instance = testing::UnitTest::GetInstance();
- int count = 0;
-
- for (int i = 0; i < instance->total_test_case_count(); ++i) {
- const testing::TestCase& test_case = *instance->GetTestCase(i);
- for (int j = 0; j < test_case.total_test_count(); ++j) {
- if (test_match(*test_case.GetTestInfo(j))) {
- count++;
- }
- }
- }
-
- return count;
-}
-
void TestSuite::CatchMaybeTests() {
testing::TestEventListeners& listeners =
testing::UnitTest::GetInstance()->listeners();
@@ -194,17 +158,6 @@ int TestSuite::Run() {
#endif
int result = RUN_ALL_TESTS();
- // If there are failed tests, see if we should ignore the failures.
- if (result != 0 && GetTestCount(&TestSuite::NonIgnoredFailures) == 0)
- result = 0;
-
- // Display the number of flaky tests.
- int flaky_count = GetTestCount(&TestSuite::IsMarkedFlaky);
- if (flaky_count) {
- printf(" YOU HAVE %d FLAKY %s\n\n", flaky_count,
- flaky_count == 1 ? "TEST" : "TESTS");
- }
-
#if defined(OS_MACOSX)
// This MUST happen before Shutdown() since Shutdown() tears down
// objects (such as NotificationService::current()) that Cocoa
diff --git a/base/test/test_suite.h b/base/test/test_suite.h
index 1758f86..9f139ed 100644
--- a/base/test/test_suite.h
+++ b/base/test/test_suite.h
@@ -28,36 +28,17 @@ class TestSuite {
TestSuite(int argc, char** argv);
virtual ~TestSuite();
- // Returns true if the test is marked as flaky.
- static bool IsMarkedFlaky(const testing::TestInfo& test);
-
- // Returns true if the test is marked as failing.
- static bool IsMarkedFailing(const testing::TestInfo& test);
-
// Returns true if the test is marked as "MAYBE_".
// When using different prefixes depending on platform, we use MAYBE_ and
// preprocessor directives to replace MAYBE_ with the target prefix.
static bool IsMarkedMaybe(const testing::TestInfo& test);
- // Returns true if the test failure should be ignored.
- static bool ShouldIgnoreFailure(const testing::TestInfo& test);
-
- // Returns true if the test failed and the failure shouldn't be ignored.
- static bool NonIgnoredFailures(const testing::TestInfo& test);
-
- // Returns the number of tests where the match function returns true.
- int GetTestCount(TestMatch test_match);
-
void CatchMaybeTests();
void ResetCommandLine();
int Run();
- // A command-line flag that makes a test failure always result in a non-zero
- // process exit code.
- static const char kStrictFailureHandling[];
-
protected:
// This constructor is only accessible to specialized test suite
// implementations which need to control the creation of an AtExitManager
diff --git a/chrome/browser/browser_keyevents_browsertest.cc b/chrome/browser/browser_keyevents_browsertest.cc
index 5381581..dab20b0 100644
--- a/chrome/browser/browser_keyevents_browsertest.cc
+++ b/chrome/browser/browser_keyevents_browsertest.cc
@@ -806,7 +806,7 @@ IN_PROC_BROWSER_TEST_F(BrowserKeyEventsTest, EditorKeyBindings) {
#endif
// See http://crbug.com/147579
-IN_PROC_BROWSER_TEST_F(BrowserKeyEventsTest, FLAKY_PageUpDownKeys) {
+IN_PROC_BROWSER_TEST_F(BrowserKeyEventsTest, DISABLED_PageUpDownKeys) {
static const KeyEventTestData kTestPageUp = {
ui::VKEY_PRIOR, false, false, false, false,
false, false, false, false, 2,
diff --git a/chrome/browser/extensions/api/management/management_browsertest.cc b/chrome/browser/extensions/api/management/management_browsertest.cc
index aee9ef5..1ffb3ca 100644
--- a/chrome/browser/extensions/api/management/management_browsertest.cc
+++ b/chrome/browser/extensions/api/management/management_browsertest.cc
@@ -115,7 +115,7 @@ IN_PROC_BROWSER_TEST_F(ExtensionManagementTest, InstallThenCancel) {
#if defined(OS_WIN)
// http://crbug.com/141913
-#define MAYBE_InstallRequiresConfirm FLAKY_InstallRequiresConfirm
+#define MAYBE_InstallRequiresConfirm DISABLED_InstallRequiresConfirm
#else
#define MAYBE_InstallRequiresConfirm InstallRequiresConfirm
#endif
diff --git a/chrome/browser/extensions/api/record/record_api_test.cc b/chrome/browser/extensions/api/record/record_api_test.cc
index ad095b9..c81dbe1 100644
--- a/chrome/browser/extensions/api/record/record_api_test.cc
+++ b/chrome/browser/extensions/api/record/record_api_test.cc
@@ -272,7 +272,7 @@ class RecordApiTest : public InProcessBrowserTest {
};
-IN_PROC_BROWSER_TEST_F(RecordApiTest, FLAKY_CheckCapture) {
+IN_PROC_BROWSER_TEST_F(RecordApiTest, DISABLED_CheckCapture) {
base::ScopedTempDir user_data_dir;
scoped_ptr<base::ListValue> result;
diff --git a/chrome/browser/extensions/crx_installer_browsertest.cc b/chrome/browser/extensions/crx_installer_browsertest.cc
index fef8f7c..d8bc458 100644
--- a/chrome/browser/extensions/crx_installer_browsertest.cc
+++ b/chrome/browser/extensions/crx_installer_browsertest.cc
@@ -229,7 +229,7 @@ IN_PROC_BROWSER_TEST_F(
// Tests that scopes are only granted if |record_oauth2_grant_| on the prompt is
// true.
#if defined(OS_WIN)
-#define MAYBE_GrantScopes FLAKY_GrantScopes
+#define MAYBE_GrantScopes DISABLED_GrantScopes
#else
#define MAYBE_GrantScopes GrantScopes
#endif
diff --git a/chrome/browser/extensions/extension_resource_request_policy_apitest.cc b/chrome/browser/extensions/extension_resource_request_policy_apitest.cc
index fe6eb22..cb4c481 100644
--- a/chrome/browser/extensions/extension_resource_request_policy_apitest.cc
+++ b/chrome/browser/extensions/extension_resource_request_policy_apitest.cc
@@ -266,7 +266,7 @@ IN_PROC_BROWSER_TEST_F(ExtensionResourceRequestPolicyTest, Iframe) {
}
#if defined(OS_MACOSX)
-#define MAYBE_ExtensionAccessibleResources FLAKY_ExtensionAccessibleResources
+#define MAYBE_ExtensionAccessibleResources DISABLED_ExtensionAccessibleResources
#else
#define MAYBE_ExtensionAccessibleResources ExtensionAccessibleResources
#endif
diff --git a/chrome/browser/extensions/extension_tabs_apitest.cc b/chrome/browser/extensions/extension_tabs_apitest.cc
index e11172e..29a8fce 100644
--- a/chrome/browser/extensions/extension_tabs_apitest.cc
+++ b/chrome/browser/extensions/extension_tabs_apitest.cc
@@ -87,7 +87,7 @@ IN_PROC_BROWSER_TEST_F(ExtensionApiTest, Tabs2) {
}
// crbug.com/149924
-IN_PROC_BROWSER_TEST_F(ExtensionApiTest, FLAKY_TabDuplicate) {
+IN_PROC_BROWSER_TEST_F(ExtensionApiTest, DISABLED_TabDuplicate) {
ASSERT_TRUE(RunExtensionSubtest("tabs/basics", "duplicate.html")) << message_;
}
diff --git a/chrome/browser/history/history_unittest.cc b/chrome/browser/history/history_unittest.cc
index 7ec66b8..44b7247 100644
--- a/chrome/browser/history/history_unittest.cc
+++ b/chrome/browser/history/history_unittest.cc
@@ -708,7 +708,7 @@ TEST_F(HistoryTest, SetTitle) {
}
// crbug.com/159387: This test fails when daylight savings time ends.
-TEST_F(HistoryTest, FLAKY_Segments) {
+TEST_F(HistoryTest, DISABLED_Segments) {
ASSERT_TRUE(history_service_.get());
static const void* scope = static_cast<void*>(this);
diff --git a/chrome/browser/logging_chrome_browsertest.cc b/chrome/browser/logging_chrome_browsertest.cc
index c75320f..cf155d0 100644
--- a/chrome/browser/logging_chrome_browsertest.cc
+++ b/chrome/browser/logging_chrome_browsertest.cc
@@ -90,7 +90,7 @@ class RendererCrashTest : public InProcessBrowserTest,
};
// Flaky, http://crbug.com/107226 .
-IN_PROC_BROWSER_TEST_F(RendererCrashTest, FLAKY_Crash) {
+IN_PROC_BROWSER_TEST_F(RendererCrashTest, DISABLED_Crash) {
registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
content::NotificationService::AllSources());
ui_test_utils::NavigateToURLWithDisposition(
diff --git a/chrome/browser/net/load_timing_observer_browsertest.cc b/chrome/browser/net/load_timing_observer_browsertest.cc
index cea21c5..d7be0c5 100644
--- a/chrome/browser/net/load_timing_observer_browsertest.cc
+++ b/chrome/browser/net/load_timing_observer_browsertest.cc
@@ -17,7 +17,7 @@ class LoadTimingObserverTest : public InProcessBrowserTest {
};
// http://crbug.com/102030
-IN_PROC_BROWSER_TEST_F(LoadTimingObserverTest, FLAKY_CacheHitAfterRedirect) {
+IN_PROC_BROWSER_TEST_F(LoadTimingObserverTest, DISABLED_CacheHitAfterRedirect) {
ASSERT_TRUE(test_server()->Start());
GURL cached_page = test_server()->GetURL("cachetime");
std::string redirect = "server-redirect?" + cached_page.spec();
diff --git a/chrome/browser/performance_monitor/performance_monitor_browsertest.cc b/chrome/browser/performance_monitor/performance_monitor_browsertest.cc
index 07573c0c..d54f5b5 100644
--- a/chrome/browser/performance_monitor/performance_monitor_browsertest.cc
+++ b/chrome/browser/performance_monitor/performance_monitor_browsertest.cc
@@ -552,7 +552,8 @@ IN_PROC_BROWSER_TEST_F(PerformanceMonitorBrowserTest, NewVersionEvent) {
}
// crbug.com/160502
-IN_PROC_BROWSER_TEST_F(PerformanceMonitorBrowserTest, FLAKY_GatherStatistics) {
+IN_PROC_BROWSER_TEST_F(PerformanceMonitorBrowserTest,
+ DISABLED_GatherStatistics) {
GatherStatistics();
// No stats should be recorded for this CPUUsage because this was the first
diff --git a/chrome/browser/prerender/prerender_browsertest.cc b/chrome/browser/prerender/prerender_browsertest.cc
index 8a029c5..8e9ddd7 100644
--- a/chrome/browser/prerender/prerender_browsertest.cc
+++ b/chrome/browser/prerender/prerender_browsertest.cc
@@ -1350,7 +1350,7 @@ IN_PROC_BROWSER_TEST_F(PrerenderBrowserTest, PrerenderAlertAfterOnload) {
#define MAYBE_PrerenderDelayLoadPlugin DISABLED_PrerenderDelayLoadPlugin
#elif defined(OS_MACOSX)
// http://crbug.com/100514
-#define MAYBE_PrerenderDelayLoadPlugin FLAKY_PrerenderDelayLoadPlugin
+#define MAYBE_PrerenderDelayLoadPlugin DISABLED_PrerenderDelayLoadPlugin
#else
#define MAYBE_PrerenderDelayLoadPlugin PrerenderDelayLoadPlugin
#endif
diff --git a/chrome/browser/printing/print_dialog_cloud_interative_uitest.cc b/chrome/browser/printing/print_dialog_cloud_interative_uitest.cc
index 071c9b8..f6a72e5 100644
--- a/chrome/browser/printing/print_dialog_cloud_interative_uitest.cc
+++ b/chrome/browser/printing/print_dialog_cloud_interative_uitest.cc
@@ -257,7 +257,7 @@ net::URLRequestJob* PrintDialogCloudTest::Factory(
}
#if defined(OS_WIN)
-#define MAYBE_HandlersRegistered FLAKY_HandlersRegistered
+#define MAYBE_HandlersRegistered DISABLED_HandlersRegistered
#else
#define MAYBE_HandlersRegistered HandlersRegistered
#endif
diff --git a/chrome/browser/sync/profile_sync_service_unittest.cc b/chrome/browser/sync/profile_sync_service_unittest.cc
index a125be1..7c420e7 100644
--- a/chrome/browser/sync/profile_sync_service_unittest.cc
+++ b/chrome/browser/sync/profile_sync_service_unittest.cc
@@ -437,7 +437,7 @@ TEST_F(ProfileSyncServiceTest, FailToDownloadControlTypes) {
// reenable sync. The handler should get notified of the state
// changes.
// Flaky on all platforms. http://crbug.com/154491
-TEST_F(ProfileSyncServiceTest, FLAKY_DisableInvalidationsOnStop) {
+TEST_F(ProfileSyncServiceTest, DISABLED_DisableInvalidationsOnStop) {
harness_.StartSyncServiceAndSetInitialSyncEnded(
true, true, true, true, syncer::STORAGE_IN_MEMORY);
diff --git a/chrome/browser/sync/test/integration/sync_errors_test.cc b/chrome/browser/sync/test/integration/sync_errors_test.cc
index 53c7395..fb8b16b 100644
--- a/chrome/browser/sync/test/integration/sync_errors_test.cc
+++ b/chrome/browser/sync/test/integration/sync_errors_test.cc
@@ -162,7 +162,7 @@ IN_PROC_BROWSER_TEST_F(SyncErrorTest, AuthErrorTest) {
// other auth error.
// This has been flaking a lot recently on Mac. http://crbug.com/165328
#if defined(OS_MACOSX)
-#define MAYBE_XmppAuthErrorTest FLAKY_XmppAuthErrorTest
+#define MAYBE_XmppAuthErrorTest DISABLED_XmppAuthErrorTest
#else
#define MAYBE_XmppAuthErrorTest XmppAuthErrorTest
#endif
diff --git a/chrome/browser/tab_restore_browsertest.cc b/chrome/browser/tab_restore_browsertest.cc
index c37cce9..750ab02 100644
--- a/chrome/browser/tab_restore_browsertest.cc
+++ b/chrome/browser/tab_restore_browsertest.cc
@@ -212,7 +212,7 @@ IN_PROC_BROWSER_TEST_F(TabRestoreTest, RestoreToDifferentWindow) {
// Close a tab, open a new window, close the first window, then restore the
// tab. It should be in a new window.
// If this becomes flaky, use http://crbug.com/14774
-IN_PROC_BROWSER_TEST_F(TabRestoreTest, FLAKY_BasicRestoreFromClosedWindow) {
+IN_PROC_BROWSER_TEST_F(TabRestoreTest, DISABLED_BasicRestoreFromClosedWindow) {
// Navigate to url1 then url2.
ui_test_utils::NavigateToURL(browser(), url1_);
ui_test_utils::NavigateToURL(browser(), url2_);
diff --git a/chrome/browser/ui/panels/panel_browsertest.cc b/chrome/browser/ui/panels/panel_browsertest.cc
index 228ca2b..61135e0 100644
--- a/chrome/browser/ui/panels/panel_browsertest.cc
+++ b/chrome/browser/ui/panels/panel_browsertest.cc
@@ -401,7 +401,7 @@ class WaitForAutoResizeNarrower : public TestPanelNotificationObserver {
};
// crbug.com/160504
-IN_PROC_BROWSER_TEST_F(PanelBrowserTest, FLAKY_AutoResize) {
+IN_PROC_BROWSER_TEST_F(PanelBrowserTest, DISABLED_AutoResize) {
PanelManager* panel_manager = PanelManager::GetInstance();
panel_manager->enable_auto_sizing(true);
// Bigger space is needed by this test.
diff --git a/chrome/browser/ui/webui/options/chromeos/guest_mode_options_ui_browsertest.cc b/chrome/browser/ui/webui/options/chromeos/guest_mode_options_ui_browsertest.cc
index ed5969a..13c34c6 100644
--- a/chrome/browser/ui/webui/options/chromeos/guest_mode_options_ui_browsertest.cc
+++ b/chrome/browser/ui/webui/options/chromeos/guest_mode_options_ui_browsertest.cc
@@ -20,7 +20,7 @@ class GuestModeOptionsBrowserTest : public options::OptionsBrowserTest {
}
};
-IN_PROC_BROWSER_TEST_F(GuestModeOptionsBrowserTest, FLAKY_LoadOptionsByURL) {
+IN_PROC_BROWSER_TEST_F(GuestModeOptionsBrowserTest, DISABLED_LoadOptionsByURL) {
NavigateToSettings();
VerifyTitle();
VerifyNavbar();
diff --git a/chrome/browser/ui/webui/options/options_ui_browsertest.cc b/chrome/browser/ui/webui/options/options_ui_browsertest.cc
index 5afe3ba..13111a5 100644
--- a/chrome/browser/ui/webui/options/options_ui_browsertest.cc
+++ b/chrome/browser/ui/webui/options/options_ui_browsertest.cc
@@ -42,7 +42,7 @@ void OptionsBrowserTest::VerifyTitle() {
}
// Flaky, see http://crbug.com/119671.
-IN_PROC_BROWSER_TEST_F(OptionsBrowserTest, FLAKY_LoadOptionsByURL) {
+IN_PROC_BROWSER_TEST_F(OptionsBrowserTest, DISABLED_LoadOptionsByURL) {
NavigateToSettings();
VerifyTitle();
VerifyNavbar();
diff --git a/chrome/common/time_format_unittest.cc b/chrome/common/time_format_unittest.cc
index cc30a48c..2b8c6b1 100644
--- a/chrome/common/time_format_unittest.cc
+++ b/chrome/common/time_format_unittest.cc
@@ -49,7 +49,7 @@ TEST(TimeFormat, FormatTime) {
}
// crbug.com/159388: This test fails when daylight savings time ends.
-TEST(TimeFormat, FLAKY_RelativeDate) {
+TEST(TimeFormat, RelativeDate) {
base::Time now = base::Time::Now();
string16 today_str = TimeFormat::RelativeDate(now, NULL);
EXPECT_EQ(ASCIIToUTF16("Today"), today_str);
diff --git a/chrome/test/data/webui/ntp4.js b/chrome/test/data/webui/ntp4.js
index e295070..3c5c2b3 100644
--- a/chrome/test/data/webui/ntp4.js
+++ b/chrome/test/data/webui/ntp4.js
@@ -31,7 +31,7 @@ TEST_F('NTP4WebUITest', 'TestBrowsePages', function() {
});
// http://crbug.com/118944
-TEST_F('NTP4WebUITest', 'FLAKY_NTPHasThumbnails', function() {
+TEST_F('NTP4WebUITest', 'DISABLED_NTPHasThumbnails', function() {
var mostVisited = document.querySelectorAll('.most-visited');
assertEquals(8, mostVisited.length, 'There should be 8 most visited tiles.');
diff --git a/chrome/test/ppapi/ppapi_browsertest.cc b/chrome/test/ppapi/ppapi_browsertest.cc
index 9e8d6ad..5a5d1ac 100644
--- a/chrome/test/ppapi/ppapi_browsertest.cc
+++ b/chrome/test/ppapi/ppapi_browsertest.cc
@@ -467,7 +467,7 @@ TEST_PPAPI_OUT_OF_PROCESS_VIA_HTTP(URLRequest_CreateAndIsURLRequestInfo)
// Timing out on Windows. http://crbug.com/129571
#if defined(OS_WIN)
#define MAYBE_URLRequest_CreateAndIsURLRequestInfo \
- FLAKY_URLRequest_CreateAndIsURLRequestInfo
+ DISABLED_URLRequest_CreateAndIsURLRequestInfo
#else
#define MAYBE_URLRequest_CreateAndIsURLRequestInfo \
URLRequest_CreateAndIsURLRequestInfo
diff --git a/chrome_frame/test/navigation_test.cc b/chrome_frame/test/navigation_test.cc
index a61ae92..f6c287a 100644
--- a/chrome_frame/test/navigation_test.cc
+++ b/chrome_frame/test/navigation_test.cc
@@ -600,7 +600,7 @@ class NavigationTest : public MockIEEventSinkTest, public testing::Test {
// Test navigation to a disallowed gcf: url with file scheme.
// Times out sporadically; http://crbug.com/119718.
-TEST_F(NavigationTest, FLAKY_GcfProtocol1) {
+TEST_F(NavigationTest, DISABLED_GcfProtocol1) {
// Make sure that we are not accidently enabling gcf protocol.
SetConfigBool(kAllowUnsafeURLs, false);
TestDisAllowedUrl(L"gcf:file:///C:/");
diff --git a/chrome_frame/test/test_with_web_server.cc b/chrome_frame/test/test_with_web_server.cc
index b43b4d7..277675a 100644
--- a/chrome_frame/test/test_with_web_server.cc
+++ b/chrome_frame/test/test_with_web_server.cc
@@ -464,7 +464,8 @@ const wchar_t kNavigateURLRelativePage[] =
L"navigateurl_relative_host.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_WidgetModeIE_NavigateURLRelative) {
+TEST_F(ChromeFrameTestWithWebServer,
+ DISABLED_WidgetModeIE_NavigateURLRelative) {
SimpleBrowserTest(IE, kNavigateURLRelativePage);
}
@@ -478,7 +479,7 @@ const wchar_t kiframeBasicPage[] = L"iframe_basic_host.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_WidgetModeIE_iframeBasic) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_WidgetModeIE_iframeBasic) {
SimpleBrowserTest(IE, kiframeBasicPage);
}
@@ -515,7 +516,7 @@ TEST_F(ChromeFrameTestWithWebServer, WidgetModeIE_CFInstanceFallback) {
const wchar_t kCFINoSrcPage[] = L"CFInstance_no_src_host.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_WidgetModeIE_CFInstanceNoSrc) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_WidgetModeIE_CFInstanceNoSrc) {
SimpleBrowserTest(IE, kCFINoSrcPage);
}
@@ -647,7 +648,7 @@ TEST_F(ChromeFrameTestWithWebServer, FullTabModeIE_CFHttpHeaderFrameSet) {
const wchar_t kVersionPage[] = L"version.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_WidgetModeIE_Version) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_WidgetModeIE_Version) {
VersionTest(IE, kVersionPage);
}
@@ -665,7 +666,7 @@ TEST_F(ChromeFrameTestWithWebServer, WidgetModeIE_PrivilegedApis) {
const wchar_t kMetaTagPage[] = L"meta_tag.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_MetaTag) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_FullTabModeIE_MetaTag) {
SimpleBrowserTest(IE, kMetaTagPage);
}
@@ -710,7 +711,7 @@ const wchar_t kXMLHttpRequestTestUrl[] =
L"xmlhttprequest_test.html";
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_XHRTest) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_FullTabModeIE_XHRTest) {
SimpleBrowserTest(IE, kXMLHttpRequestTestUrl);
}
@@ -750,7 +751,7 @@ const wchar_t kXHRHeaderTestUrl[] =
L"xmlhttprequest_header_test.html";
// Marking as flaky since it occasionally times out. crbug.com/127395.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_XHRHeaderTest) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_FullTabModeIE_XHRHeaderTest) {
SimpleBrowserTest(IE, kXHRHeaderTestUrl);
}
@@ -771,7 +772,7 @@ TEST_F(ChromeFrameTestWithWebServer, FullTabModeIE_AnchorUrlNavigateTest) {
// Test whether POST-ing a form from an mshtml page to a CF page will cause
// the request to get reissued. It should not.
// https://code.google.com/p/chromium/issues/detail?id=143699
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_TestPostReissue) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_FullTabModeIE_TestPostReissue) {
// The order of pages in this array is assumed to be mshtml, cf, script.
const wchar_t* kPages[] = {
L"full_tab_post_mshtml.html",
@@ -803,7 +804,7 @@ TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_TestPostReissue) {
// Test whether following a link from an mshtml page to a CF page will cause
// multiple network requests. It should not.
// Flaky, crbug.com/160497.
-TEST_F(ChromeFrameTestWithWebServer, FLAKY_FullTabModeIE_TestMultipleGet) {
+TEST_F(ChromeFrameTestWithWebServer, DISABLED_FullTabModeIE_TestMultipleGet) {
// The order of pages in this array is assumed to be mshtml, cf, script.
const wchar_t* kPages[] = {
L"full_tab_get_mshtml.html",
diff --git a/chrome_frame/test/ui_test.cc b/chrome_frame/test/ui_test.cc
index 9d10363..bbcb4ca 100644
--- a/chrome_frame/test/ui_test.cc
+++ b/chrome_frame/test/ui_test.cc
@@ -114,7 +114,7 @@ TEST_P(FullTabUITest, DISABLED_KeyboardBackForward) {
// Tests new window behavior with ctrl+N.
// Flaky due to DelaySendChar; see http://crbug.com/124244.
-TEST_P(FullTabUITest, FLAKY_CtrlN) {
+TEST_P(FullTabUITest, DISABLED_CtrlN) {
if (IsWorkstationLocked()) {
LOG(ERROR) << "This test cannot be run in a locked workstation.";
return;
@@ -156,7 +156,7 @@ TEST_P(FullTabUITest, FLAKY_CtrlN) {
// Test that Ctrl+F opens the Find dialog.
// Flaky due to DelaySendChar; see http://crbug.com/124244.
-TEST_P(FullTabUITest, FLAKY_CtrlF) {
+TEST_P(FullTabUITest, DISABLED_CtrlF) {
if (IsWorkstationLocked()) {
LOG(ERROR) << "This test cannot be run in a locked workstation.";
return;
@@ -190,7 +190,7 @@ TEST_P(FullTabUITest, FLAKY_CtrlF) {
// Test that ctrl+r does cause a refresh.
// Flaky due to DelaySendChar; see http://crbug.com/124244.
-TEST_P(FullTabUITest, FLAKY_CtrlR) {
+TEST_P(FullTabUITest, DISABLED_CtrlR) {
if (IsWorkstationLocked()) {
LOG(ERROR) << "This test cannot be run in a locked workstation.";
return;
@@ -219,7 +219,7 @@ TEST_P(FullTabUITest, FLAKY_CtrlR) {
// Test window close with ctrl+w.
// Flaky due to DelaySendChar; see http://crbug.com/124244.
-TEST_P(FullTabUITest, FLAKY_CtrlW) {
+TEST_P(FullTabUITest, DISABLED_CtrlW) {
if (IsWorkstationLocked()) {
LOG(ERROR) << "This test cannot be run in a locked workstation.";
return;
@@ -240,7 +240,7 @@ TEST_P(FullTabUITest, FLAKY_CtrlW) {
// Test address bar navigation with Alt+d and URL.
// Flaky due to TypeUrlInAddressBar; see http://crbug.com/124244.
-TEST_P(FullTabUITest, FLAKY_AltD) {
+TEST_P(FullTabUITest, DISABLED_AltD) {
if (IsWorkstationLocked()) {
LOG(ERROR) << "This test cannot be run in a locked workstation.";
return;
@@ -809,7 +809,7 @@ TEST_F(ContextMenuTest, CFCopyLinkAddress) {
// Test CF text field context menu - cut.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldCut) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldCut) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
@@ -833,7 +833,7 @@ TEST_F(ContextMenuTest, FLAKY_CFTxtFieldCut) {
// Test CF text field context menu - copy.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldCopy) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldCopy) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
@@ -859,7 +859,7 @@ TEST_F(ContextMenuTest, FLAKY_CFTxtFieldCopy) {
// Test CF text field context menu - paste.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldPaste) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldPaste) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
@@ -883,7 +883,7 @@ TEST_F(ContextMenuTest, FLAKY_CFTxtFieldPaste) {
// Test CF text field context menu - delete.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldDelete) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldDelete) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
@@ -925,7 +925,7 @@ TEST_F(ContextMenuTest, DISABLED_CFTxtFieldSelectAll) {
// Test CF text field context menu - undo.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldUndo) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldUndo) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
@@ -953,7 +953,7 @@ TEST_F(ContextMenuTest, FLAKY_CFTxtFieldUndo) {
// Test CF text field context menu - redo.
// Times out sporadically http://crbug.com/119660.
-TEST_F(ContextMenuTest, FLAKY_CFTxtFieldRedo) {
+TEST_F(ContextMenuTest, DISABLED_CFTxtFieldRedo) {
server_mock_.ExpectAndServeAnyRequests(CFInvocation::MetaTag());
AccObjectMatcher txtfield_matcher(L"", L"editable text");
InSequence expect_in_sequence_for_scope;
diff --git a/content/public/test/test_launcher.cc b/content/public/test/test_launcher.cc
index ff2df30..8df8d48 100644
--- a/content/public/test/test_launcher.cc
+++ b/content/public/test/test_launcher.cc
@@ -422,10 +422,6 @@ int RunTest(TestLauncherDelegate* launcher_delegate,
new_cmd_line.AppendSwitchNative((*iter).first, (*iter).second);
}
- // Do not let the child ignore failures. We need to propagate the
- // failure status back to the parent.
- new_cmd_line.AppendSwitch(base::TestSuite::kStrictFailureHandling);
-
base::ScopedTempDir temp_dir;
// Create a new data dir and pass it to the child.
if (!temp_dir.CreateUniqueTempDir() || !temp_dir.IsValid()) {
diff --git a/dbus/bus_unittest.cc b/dbus/bus_unittest.cc
index 769b6d7..ca24041 100644
--- a/dbus/bus_unittest.cc
+++ b/dbus/bus_unittest.cc
@@ -109,7 +109,7 @@ TEST(BusTest, GetExportedObject) {
}
// http://crbug.com/137846
-TEST(BusTest, FLAKY_UnregisterExportedObject) {
+TEST(BusTest, DISABLED_UnregisterExportedObject) {
// Start the D-Bus thread.
base::Thread::Options thread_options;
thread_options.message_loop_type = MessageLoop::TYPE_IO;
diff --git a/media/ffmpeg/ffmpeg_regression_tests.cc b/media/ffmpeg/ffmpeg_regression_tests.cc
index ba0d084..923a610 100644
--- a/media/ffmpeg/ffmpeg_regression_tests.cc
+++ b/media/ffmpeg/ffmpeg_regression_tests.cc
@@ -86,8 +86,8 @@ class FlakyFFmpegRegressionTest
video_md5, \
audio_md5)));
-#define FLAKY_FFMPEG_TEST_CASE(name, fn) \
- INSTANTIATE_TEST_CASE_P(FLAKY_##name, FlakyFFmpegRegressionTest, \
+#define DISABLED_FFMPEG_TEST_CASE(name, fn) \
+ INSTANTIATE_TEST_CASE_P(DISABLED_##name, FlakyFFmpegRegressionTest, \
testing::Values(FlakyRegressionTestData(fn)));
// Test cases from issues.
@@ -304,25 +304,25 @@ FFMPEG_TEST_CASE(BIG_MEM_2, "security/looping1.mov",
FFMPEG_TEST_CASE(BIG_MEM_5, "security/looping5.mov",
DEMUXER_ERROR_COULD_NOT_OPEN, DEMUXER_ERROR_COULD_NOT_OPEN,
kNullHash, kNullHash);
-FLAKY_FFMPEG_TEST_CASE(BIG_MEM_3, "security/looping3.mov");
-FLAKY_FFMPEG_TEST_CASE(BIG_MEM_4, "security/looping4.mov");
+DISABLED_FFMPEG_TEST_CASE(BIG_MEM_3, "security/looping3.mov");
+DISABLED_FFMPEG_TEST_CASE(BIG_MEM_4, "security/looping4.mov");
// Flaky under threading or for other reasons. Per rbultje, most of these will
// never be reliable since FFmpeg does not guarantee consistency in error cases.
// We only really care that these don't cause crashes or errors under tooling.
-FLAKY_FFMPEG_TEST_CASE(Cr99652, "security/99652.webm");
-FLAKY_FFMPEG_TEST_CASE(Cr100464, "security/100464.webm");
-FLAKY_FFMPEG_TEST_CASE(Cr111342, "security/111342.ogm");
-FLAKY_FFMPEG_TEST_CASE(OGV_0, "security/big_dims.ogv");
-FLAKY_FFMPEG_TEST_CASE(OGV_3, "security/smclock_1_0.ogv");
-FLAKY_FFMPEG_TEST_CASE(OGV_4, "security/smclock.ogv.1.0.ogv");
-FLAKY_FFMPEG_TEST_CASE(OGV_6, "security/smclocktheora_1_10000.ogv");
-FLAKY_FFMPEG_TEST_CASE(OGV_13, "security/smclocktheora_1_790.ogv");
-FLAKY_FFMPEG_TEST_CASE(MP4_3, "security/clockh264aac_300413969.mp4");
-FLAKY_FFMPEG_TEST_CASE(MP4_4, "security/clockh264aac_301350139.mp4");
-FLAKY_FFMPEG_TEST_CASE(MP4_12, "security/assert1.mov");
+DISABLED_FFMPEG_TEST_CASE(Cr99652, "security/99652.webm");
+DISABLED_FFMPEG_TEST_CASE(Cr100464, "security/100464.webm");
+DISABLED_FFMPEG_TEST_CASE(Cr111342, "security/111342.ogm");
+DISABLED_FFMPEG_TEST_CASE(OGV_0, "security/big_dims.ogv");
+DISABLED_FFMPEG_TEST_CASE(OGV_3, "security/smclock_1_0.ogv");
+DISABLED_FFMPEG_TEST_CASE(OGV_4, "security/smclock.ogv.1.0.ogv");
+DISABLED_FFMPEG_TEST_CASE(OGV_6, "security/smclocktheora_1_10000.ogv");
+DISABLED_FFMPEG_TEST_CASE(OGV_13, "security/smclocktheora_1_790.ogv");
+DISABLED_FFMPEG_TEST_CASE(MP4_3, "security/clockh264aac_300413969.mp4");
+DISABLED_FFMPEG_TEST_CASE(MP4_4, "security/clockh264aac_301350139.mp4");
+DISABLED_FFMPEG_TEST_CASE(MP4_12, "security/assert1.mov");
// Not really flaky, but can't pass the seek test.
-FLAKY_FFMPEG_TEST_CASE(MP4_10, "security/null1.m4a");
+DISABLED_FFMPEG_TEST_CASE(MP4_10, "security/null1.m4a");
// Videos with massive gaps between frame timestamps that result in long hangs
// with our pipeline. Should be uncommented when we support clockless playback.
diff --git a/net/dns/dns_config_service_unittest.cc b/net/dns/dns_config_service_unittest.cc
index c89f35b..af2c221 100644
--- a/net/dns/dns_config_service_unittest.cc
+++ b/net/dns/dns_config_service_unittest.cc
@@ -242,7 +242,7 @@ TEST_F(DnsConfigServiceTest, WatchFailure) {
#if (defined(OS_POSIX) && !defined(OS_ANDROID)) || defined(OS_WIN)
// TODO(szym): This is really an integration test and can time out if HOSTS is
// huge. http://crbug.com/107810
-TEST_F(DnsConfigServiceTest, FLAKY_GetSystemConfig) {
+TEST_F(DnsConfigServiceTest, DISABLED_GetSystemConfig) {
service_.reset();
scoped_ptr<DnsConfigService> service(DnsConfigService::CreateSystemService());
diff --git a/net/url_request/url_request_unittest.cc b/net/url_request/url_request_unittest.cc
index 977c616..bd21b38 100644
--- a/net/url_request/url_request_unittest.cc
+++ b/net/url_request/url_request_unittest.cc
@@ -1368,7 +1368,7 @@ class LocalHttpTestServer : public TestServer {
FilePath()) {}
};
-TEST_F(URLRequestTest, FLAKY_DelayedCookieCallback) {
+TEST_F(URLRequestTest, DISABLED_DelayedCookieCallback) {
LocalHttpTestServer test_server;
ASSERT_TRUE(test_server.Start());
@@ -2053,7 +2053,7 @@ class URLRequestTestHTTP : public URLRequestTest {
// The HTTPTestServer will return a 302 response, which we should not
// follow.
// flaky: crbug.com/96594
-TEST_F(URLRequestTestHTTP, FLAKY_ProxyTunnelRedirectTest) {
+TEST_F(URLRequestTestHTTP, DISABLED_ProxyTunnelRedirectTest) {
ASSERT_TRUE(test_server_.Start());
TestNetworkDelegate network_delegate; // Must outlive URLRequest.
@@ -4849,7 +4849,7 @@ class URLRequestTestFTP : public URLRequestTest {
};
// Make sure an FTP request using an unsafe ports fails.
-TEST_F(URLRequestTestFTP, FLAKY_UnsafePort) {
+TEST_F(URLRequestTestFTP, DISABLED_UnsafePort) {
ASSERT_TRUE(test_server_.Start());
URLRequestJobFactoryImpl job_factory;
diff --git a/remoting/host/linux/x_server_clipboard_unittest.cc b/remoting/host/linux/x_server_clipboard_unittest.cc
index b7b8a4e..beb7f61 100644
--- a/remoting/host/linux/x_server_clipboard_unittest.cc
+++ b/remoting/host/linux/x_server_clipboard_unittest.cc
@@ -96,7 +96,7 @@ class XServerClipboardTest : public testing::Test {
};
// http://crbug.com/163428
-TEST_F(XServerClipboardTest, FLAKY_CopyPaste) {
+TEST_F(XServerClipboardTest, DISABLED_CopyPaste) {
// Verify clipboard data can be transferred more than once. Then verify that
// the code continues to function in the opposite direction (so client1_ will
// send then receive, and client2_ will receive then send).
diff --git a/chrome/test/data/webui/sandboxstatus_browsertest.js b/chrome/test/data/webui/sandboxstatus_browsertest.js
index 8128ec8..daff80b 100644
--- a/chrome/test/data/webui/sandboxstatus_browsertest.js
+++ b/chrome/test/data/webui/sandboxstatus_browsertest.js
@@ -24,9 +24,7 @@ SandboxStatusUITest.prototype = {
// the proper way to address such failures is to install the SUID
// sandbox. See:
// http://code.google.com/p/chromium/wiki/LinuxSUIDSandboxDevelopment
-// - PLEASE DO NOT DISABLE THIS TEST. If you can't figure out how to
-// get the SUID sandbox installed, please mark the test FLAKY_ so we
-// can get clear information on where the sandbox is and isn't installed.
+// - PLEASE DO NOT GLOBALLY DISABLE THIS TEST.
// SUID sandbox is currently incompatible with AddressSanitizer,
// see http://crbug.com/137653.
GEN('#if defined(OS_LINUX) && !defined(ADDRESS_SANITIZER)');
@@ -40,7 +38,7 @@ GEN('#endif');
/**
* Test if the SUID sandbox is enabled.
*
* TODO(bradchen): Remove FLAKY_ and flip polarity of this test once
* the SUID sandbox is enabled on the Chromium bots. In the mean time
* this test will make it clear that the enabling steps are effective.
*/
@@ -58,7 +56,7 @@ TEST_F('SandboxStatusUITest', 'MAYBE_testSUIDSandboxEnabled', function() {
// The seccomp-bpf sandbox is also not compatible with ASAN.
GEN('#if defined(OS_LINUX) && !defined(ADDRESS_SANITIZER)');
GEN('# define MAYBE_testBPFSandboxEnabled \\');
-GEN(' FLAKY_testBPFSandboxEnabled');
+GEN(' DISABLED_testBPFSandboxEnabled');
GEN('#else');
GEN('# define MAYBE_testBPFSandboxEnabled \\');
GEN(' DISABLED_testBPFSandboxEnabled');
@@ -67,7 +65,7 @@ GEN('#endif');
/**
* Test if the seccomp-bpf sandbox is enabled.
* We know that some machines lack kernel support for this. So we mark
- * it as FLAKY_.
+ * it as DISABLED_.
* It's very convenient to quickly be able to check whether tests ran with
* or without the Seccomp BPF sandbox through this mechanism.
*/
@@ -40,7 +38,7 @@ GEN('#endif');
* Test if the SUID sandbox is enabled.
*
- * TODO(bradchen): Remove FLAKY_ and flip polarity of this test once
+ * TODO(bradchen): Remove DISABLED_ and flip polarity of this test once
* the SUID sandbox is enabled on the Chromium bots. In the mean time
* this test will make it clear that the enabling steps are effective.